|
|
|
|
|
|
| Synopsis |
|
|
|
|
| Filters
|
|
|
|
|
|
|
|
|
|
|
|
| FilterSpec
|
|
|
| Filtering starts at coeff nr 0 and value 0.0 (constant coeff is always zero).
The elements in FilterSpec define the next value and how many
coeffs it takes to reach this value.
|
|
|
| 0..1: lower, 1..: higher
|
|
| FilterSpec and Lists
|
|
|
| Converting a FilterSpec to a list of 512 Doubles
|
|
|
| Converting and interpolating a sequence of FilterSpecs to a list of lists. The first elemet of the
tuple, an Int, describes how many lists it takes to reach the given FilterSpec.
|
|
|
|
| Other
|
|
|
| for filter coefficient number: (0.0 .. 1.0) -> (1.0 .. 512.0)
|
|
|
| floor of ffreq
|
|
|
| the resulting list is 1 / 512 as long as the input list.
512 elements are read and their average is the next output value.
|
|
| Filterfunctions
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
|
| Produced by Haddock version 2.4.2 |