|
|
|
|
|
| Description |
| Dieses Module stellt Datentypen und Funktionen zum Umgang mit Mono- und
Stereodaten zur Verf gung. Speziell im Falle des ffnens einer WAV-Datei
ist erst zur Laufzeit bekannt, ob es sich um eine Mono- oder Stereodatei
handelt, hier wird der Typ Signal ben tigt.
|
|
| Synopsis |
|
|
|
|
| Mono and Stereo Values
|
|
|
| A mono value.
|
|
|
| A stereo value with left and right part. It is an instance of class Num
and Fractional.
| | Constructors | | Instances | |
|
|
|
| Access to the left part of a Stereo value.
|
|
|
| Access to the right part of a Stereo value.
|
|
|
| Converts a Stereo value to a Mono value (Double)
|
|
|
| Converts a Mono value (Double) to a Stereo value
|
|
|
| The range of the Double value must be between -1 and 1. If it is below 0
the left channel is turned down, if it is greater than 0 the right channel
is turned down. NOTE: This function should be replaced by a better one.
|
|
| Signal datatype
|
|
|
| A Signal is either a list of Mono values or a list of Stereo values.
| | Constructors | | Instances | |
|
|
|
| Reads a Signal from a WAV-File.
|
|
|
| Opens a Signal from a WAV-File.
|
|
|
| Writes a list of mono values to a WAV-File.
|
|
|
| Writes a list of stereo values to a WAV-File.
|
|
|
| Writes a Signal to a WAV-File.
|
|
|
|
|
| Transfroms a signal to a list of mono values.
|
|
|
| Transfroms a signal to a list of stereo values.
|
|
|
|
|
| Applies the function to the input signal. If it is a stereo signal, the
function is applied to both channels seperately.
|
|
|
| The sum of two signals
|
|
|
| The sum of a set of signals. If all signals are mono, the result will be mono.
Otherwise it will be stereo.
|
|
|
| Multiplies two signals.
|
|
|
| The Double value is added to the input signal (offset). The resulting signal will be infinie
in any case.
|
|
| Produced by Haddock version 2.4.2 |